'use strict';

const path = require('path');
const restifyPkg = require(path.dirname(require.resolve('..')) + '/../package.json');
const restify = require('..');
console.log({restifyVersion: restifyPkg.version});


const server = restify.createServer();

// server.on('InternalServer', function(req, res, err, callback) {
//     console.error(err);
//     return callback();
// });
const badRequestResponse = Buffer.from(
    'HTTP/1.1 400 Bad Request\r\n' +
    'Connection: close\r\n\r\n', 'ascii'
);
const requestTimeoutResponse = Buffer.from(
    'HTTP/1.1 408 Request Timeout\r\n' +
    'Connection: close\r\n\r\n', 'ascii'
);
const requestHeaderFieldsTooLargeResponse = Buffer.from(
    'HTTP/1.1 431 Request Header Fields Too Large\r\n' +
    'Connection: close\r\n\r\n', 'ascii'
);

server.on('clientError', function(err, socket) {
    if (socket.writable && socket.bytesWritten === 0) {
        let response;
        switch (err.code) {
            case 'HPE_HEADER_OVERFLOW':
                response = requestHeaderFieldsTooLargeResponse;
                break;
            case 'ERR_HTTP_REQUEST_TIMEOUT':
                response = requestTimeoutResponse;
                break;
            default:
                response = badRequestResponse;
                break;
        }
        socket.write(response);
    }
    socket.destroy(err);
});


server.on('clientError', function(err, socket) {
    console.error(err);
});

server.get('/api', (req, res, next) => { res.send(200); next(); });
server.listen(8080);

